@@ -74,15 +74,19 @@ if __name__ == '__main__':
     MyPaintApp().run()
     recording.append(last_stroke)
     last_stroke = []
-    print(recording)
     raw_data_json = json.dumps(recording)
     logging.info(recording)
     logging.info("Start evaluation...")
     results = utils.classify_single_recording(raw_data_json, args.model)
     n = args.n
+
+    # Print headline
+    print("{0:18s} {1:5s}".format("LaTeX Code", "Prob"))
+    print("#"*50)
     for latex, probability in results:
         if n == 0:
             break
         else:
             n -= 1
         print("{0:18s} {1:5f}".format(latex, probability))
+    print("#"*50)
