@@ -341,7 +341,7 @@ def create_adjusted_model_for_percentages(model_src, model_use):
         f.write(content)
 
 
-def evaluate_model(recording, model_folder):
+def evaluate_model(recording, model_folder, showit=False):
     """Evaluate model for a single recording."""
 
     folders = []
@@ -362,9 +362,13 @@ def evaluate_model(recording, model_folder):
             t = target_folder
             _, _, preprocessing_queue = preprocess_dataset.get_parameters(t)
             handwriting = HandwrittenData(recording)
+            if showit:
+                handwriting.show()
             handwriting.preprocessing(preprocessing_queue)
-            logging.debug("After preprocessing: %s",
-                          handwriting.get_sorted_pointlist())
+            if showit:
+                logging.debug("After preprocessing: %s",
+                              handwriting.get_sorted_pointlist())
+                handwriting.show()
         elif "feature-files" in target_folder:
             logging.info("Create feature file...")
             infofile_path = os.path.join(target_folder, "info.yml")
